@@ -1,7 +1,7 @@
 """
 Savify
 
-Tool for downloading Spotify songs to MP3 - Full Metadata & Cover Art
+Download Spotify songs to mp3 with full metadata and cover art!
 
 :Copyright: © 2020, Laurence Rawlings.
 :License: MIT (see /LICENSE).
@@ -13,7 +13,7 @@ from .types import *
 __title__ = 'Savify'
 __author__ = """Laurence Rawlings"""
 __email__ = 'contact@laurencerawlings.com'
-__version__ = '1.1.3'
+__version__ = '2.0.2'
 __license__ = 'MIT'
 __docformat__ = 'restructuredtext en'
 
